@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct;
-$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
@@ -86,7 +85,7 @@ Search::Elasticsearch::Client::6_0::Direct - Thin client with full support for E
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 SYNOPSIS
 
