@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::Indices;
-$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
@@ -18,7 +17,7 @@ Search::Elasticsearch::Client::6_0::Direct::Indices - A client for running index
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 DESCRIPTION
 
