@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::Snapshot;
-$Search::Elasticsearch::Client::6_0::Direct::Snapshot::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::Snapshot::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::Snapshot::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('snapshot');
@@ -18,7 +17,7 @@ Search::Elasticsearch::Client::6_0::Direct::Snapshot - A client for managing sna
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 DESCRIPTION
 
