@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::Tasks;
-$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('tasks');
@@ -18,7 +17,7 @@ Search::Elasticsearch::Client::6_0::Direct::Tasks - A client for accessing the T
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 DESCRIPTION
 
