@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::XPack;
-$Search::Elasticsearch::Client::6_0::Direct::XPack::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::XPack::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::XPack::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
@@ -44,7 +43,7 @@ Search::Elasticsearch::Client::6_0::Direct::XPack - Plugin providing XPack APIs
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 SYNOPSIS
 
