@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Scroll;
-$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.81';
+use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
@@ -130,7 +129,7 @@ Search::Elasticsearch::Client::6_0::Scroll - A helper module for scrolled search
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 SYNOPSIS
 
